==> jc-1.4.0.tar.gz: javax/swing/colorchooser/DefaultRGBChooserPanel.h <==
// class javax.swing.colorchooser.DefaultRGBChooserPanel

// class file dependencies
// @dep_class d547e55bb64f2ca8 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6c83b58ef8abc63e javax_swing_JComponent
// @dep_class 7c0c9df11a59950c javax_swing_JPanel
// @dep_class 6999b2dfcdbe6fcb javax_swing_colorchooser_AbstractColorChooserPanel
// @dep_class 91c2ccb1ce6a4622 javax_swing_colorchooser_DefaultRGBChooserPanel

// header file dependencies
// @dep_header javax_swing_colorchooser_AbstractColorChooserPanel

#include "javax/swing/colorchooser/AbstractColorChooserPanel.h"

#ifndef _JC_javax_swing_colorchooser_DefaultRGBChooserPanel_H_
#define _JC_javax_swing_colorchooser_DefaultRGBChooserPanel_H_

// Forward structure declarations
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_Icon$object;
struct _jc_javax_swing_JColorChooser$object;
struct _jc_javax_swing_JLabel$object;
struct _jc_javax_swing_JSlider$object;
struct _jc_javax_swing_JSpinner$object;
struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object;
struct _jc_javax_swing_event_ChangeListener$object;

// Typedefs
typedef struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$sub_refs	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel$sub_refs;
typedef struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$sub_nonrefs	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel$sub_nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$refs	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel$refs;
typedef struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$nonrefs	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel$nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object;

typedef const struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$vmethods	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel$vmethods;
typedef const struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$vtable	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel$vtable;
typedef const struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$vtype	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel$vtype;

// Constructors
extern void _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *);

// Virtual methods
extern void _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method$buildChooser$c3b4ef0d06e57808(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *);
extern struct _jc_java_lang_String$object *_jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method$getDisplayName$ec8495f8bf7d85f4(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *);
extern struct _jc_object *_jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method$getLargeDisplayIcon$b8bd57d58f27db0a(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *);
extern struct _jc_object *_jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method$getSmallDisplayIcon$3f5a81cdb2c68338(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *);
extern void _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method$installListeners$ff395aad2cf29aae(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *);
extern void _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method$paint$76f038a09cf0c480(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *, struct _jc_java_awt_Graphics$object *);
extern void _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *);
extern void _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method$uninstallChooserPanel$75ee74402cc2c672(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *, struct _jc_javax_swing_JColorChooser$object *);
extern void _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method$uninstallListeners$e12953a4e2189a5e(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *);
extern void _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method$updateChooser$ed0d27d69b57ccc5(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method_info$buildChooser$c3b4ef0d06e57808;
extern _jc_method _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method_info$getDisplayName$ec8495f8bf7d85f4;
extern _jc_method _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method_info$getLargeDisplayIcon$b8bd57d58f27db0a;
extern _jc_method _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method_info$getSmallDisplayIcon$3f5a81cdb2c68338;
extern _jc_method _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method_info$installListeners$ff395aad2cf29aae;
extern _jc_method _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method_info$paint$76f038a09cf0c480;
extern _jc_method _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method_info$this$adc93fb6bf4cbffa;
extern _jc_method _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method_info$uninstallChooserPanel$75ee74402cc2c672;
extern _jc_method _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method_info$uninstallListeners$e12953a4e2189a5e;
extern _jc_method _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method_info$updateChooser$ed0d27d69b57ccc5;

// Static methods
extern jboolean _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method$access__240$324adac9c687e7d3(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *);
extern struct _jc_javax_swing_JSlider$object *_jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method$access__241$533d96ce377df100(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *);
extern void _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method$access__2410$549043aa90a37f17(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *, jboolean);
extern struct _jc_javax_swing_JSlider$object *_jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method$access__242$e44dfccfc23f9988(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *);
extern struct _jc_javax_swing_JSlider$object *_jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method$access__243$056daf5c6cadef0d(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *);
extern jboolean _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method$access__244$452cb726821fd1df(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *);
extern void _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method$access__245$65856a5cc3e5935b(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *, jboolean);
extern struct _jc_javax_swing_JSpinner$object *_jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method$access__246$6976df6caf93b494(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *);
extern struct _jc_javax_swing_JSpinner$object *_jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method$access__247$4b6fac7c7ab3078b(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *);
extern struct _jc_javax_swing_JSpinner$object *_jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method$access__248$51345c6755664b55(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *);
extern jboolean _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method$access__249$045642368c9bf7af(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *);

// Virtual methods structure
struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$vmethods {
	void	(*buildChooser$c3b4ef0d06e57808)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *);
	struct _jc_java_lang_String$object	*(*getDisplayName$ec8495f8bf7d85f4)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *);
	struct _jc_object	*(*getLargeDisplayIcon$b8bd57d58f27db0a)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *);
	struct _jc_object	*(*getSmallDisplayIcon$3f5a81cdb2c68338)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *);
	void	(*installListeners$ff395aad2cf29aae)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *);
	void	(*paint$76f038a09cf0c480)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *, struct _jc_java_awt_Graphics$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *);
	void	(*uninstallChooserPanel$75ee74402cc2c672)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *, struct _jc_javax_swing_JColorChooser$object *);
	void	(*uninstallListeners$e12953a4e2189a5e)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *);
	void	(*updateChooser$ed0d27d69b57ccc5)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *);
};

// Vtable
struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_JPanel$vmethods	javax_swing_JPanel;
	_jc_javax_swing_colorchooser_AbstractColorChooserPanel$vmethods	javax_swing_colorchooser_AbstractColorChooserPanel;
	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel$vmethods	javax_swing_colorchooser_DefaultRGBChooserPanel;
};

// Vtype
struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$vtype {
	_jc_type			type;
	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$sub_refs {
	struct _jc_object	*colorChanger;
	struct _jc_object	*spinnerHandler;
	struct _jc_javax_swing_JSlider$object	*R;
	struct _jc_javax_swing_JSlider$object	*G;
	struct _jc_javax_swing_JSlider$object	*B;
	struct _jc_javax_swing_JLabel$object	*RLabel;
	struct _jc_javax_swing_JLabel$object	*GLabel;
	struct _jc_javax_swing_JLabel$object	*BLabel;
	struct _jc_javax_swing_JSpinner$object	*RSpinner;
	struct _jc_javax_swing_JSpinner$object	*GSpinner;
	struct _jc_javax_swing_JSpinner$object	*BSpinner;
};

// Reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$refs {
    _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$sub_refs	javax_swing_colorchooser_DefaultRGBChooserPanel;
    _jc_javax_swing_colorchooser_AbstractColorChooserPanel$sub_refs	javax_swing_colorchooser_AbstractColorChooserPanel;
    _jc_javax_swing_JPanel$sub_refs	javax_swing_JPanel;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$sub_nonrefs {
	jboolean	spinnerChange;
	jboolean	sliderChange;
	jboolean	updateChange;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_JPanel$sub_nonrefs	javax_swing_JPanel;
    _jc_javax_swing_colorchooser_AbstractColorChooserPanel$sub_nonrefs	javax_swing_colorchooser_AbstractColorChooserPanel;
    _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$sub_nonrefs	javax_swing_colorchooser_DefaultRGBChooserPanel;
};

// Object instance structure
struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object {
	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel$vtype	*vtype;
	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$vtype _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_colorchooser_DefaultRGBChooserPanel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$class_object;

#endif	/* _JC_javax_swing_colorchooser_DefaultRGBChooserPanel_H_ */

==> jc-1.4.5.tar.gz: javax/swing/colorchooser/DefaultRGBChooserPanel.h <==
// class javax.swing.colorchooser.DefaultRGBChooserPanel

// class file dependencies
// @dep_class 5a2bf6e9db456f42 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c84352ee73c7cec1 javax_swing_JComponent
// @dep_class 7c0c9df11a59950c javax_swing_JPanel
// @dep_class 6999b2dfcdbe6fcb javax_swing_colorchooser_AbstractColorChooserPanel
// @dep_class 2766ea3a769f6a0c javax_swing_colorchooser_DefaultRGBChooserPanel

// header file dependencies
// @dep_header javax_swing_colorchooser_AbstractColorChooserPanel

#include "javax/swing/colorchooser/AbstractColorChooserPanel.h"

#ifndef _JC_javax_swing_colorchooser_DefaultRGBChooserPanel_H_
#define _JC_javax_swing_colorchooser_DefaultRGBChooserPanel_H_

// Forward structure declarations
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_Icon$object;
struct _jc_javax_swing_JColorChooser$object;
struct _jc_javax_swing_JLabel$object;
struct _jc_javax_swing_JSlider$object;
struct _jc_javax_swing_JSpinner$object;
struct _jc_javax_swing_event_ChangeListener$object;

// Typedefs
typedef struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$sub_refs	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel$sub_refs;
typedef struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$sub_nonrefs	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel$sub_nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$refs	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel$refs;
typedef struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$nonrefs	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel$nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object;

typedef const struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$vmethods	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel$vmethods;
typedef const struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$vtable	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel$vtable;
typedef const struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$vtype	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel$vtype;

// Constructors
extern void _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method$buildChooser$c3b4ef0d06e57808(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method$getDisplayName$ec8495f8bf7d85f4(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method$getLargeDisplayIcon$b8bd57d58f27db0a(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method$getSmallDisplayIcon$3f5a81cdb2c68338(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method$installListeners$ff395aad2cf29aae(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method$paint$76f038a09cf0c480(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *, struct _jc_java_awt_Graphics$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method$uninstallChooserPanel$75ee74402cc2c672(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *, struct _jc_javax_swing_JColorChooser$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method$uninstallListeners$e12953a4e2189a5e(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method$updateChooser$ed0d27d69b57ccc5(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method_info$buildChooser$c3b4ef0d06e57808;
extern _jc_method _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method_info$getDisplayName$ec8495f8bf7d85f4;
extern _jc_method _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method_info$getLargeDisplayIcon$b8bd57d58f27db0a;
extern _jc_method _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method_info$getSmallDisplayIcon$3f5a81cdb2c68338;
extern _jc_method _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method_info$installListeners$ff395aad2cf29aae;
extern _jc_method _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method_info$paint$76f038a09cf0c480;
extern _jc_method _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method_info$this$adc93fb6bf4cbffa;
extern _jc_method _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method_info$uninstallChooserPanel$75ee74402cc2c672;
extern _jc_method _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method_info$uninstallListeners$e12953a4e2189a5e;
extern _jc_method _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$method_info$updateChooser$ed0d27d69b57ccc5;

// Virtual methods structure
struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$vmethods {
	void	(*buildChooser$c3b4ef0d06e57808)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getDisplayName$ec8495f8bf7d85f4)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getLargeDisplayIcon$b8bd57d58f27db0a)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getSmallDisplayIcon$3f5a81cdb2c68338)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *) _JC_JCNI_ATTR;
	void	(*installListeners$ff395aad2cf29aae)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *) _JC_JCNI_ATTR;
	void	(*paint$76f038a09cf0c480)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *, struct _jc_java_awt_Graphics$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *) _JC_JCNI_ATTR;
	void	(*uninstallChooserPanel$75ee74402cc2c672)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *, struct _jc_javax_swing_JColorChooser$object *) _JC_JCNI_ATTR;
	void	(*uninstallListeners$e12953a4e2189a5e)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *) _JC_JCNI_ATTR;
	void	(*updateChooser$ed0d27d69b57ccc5)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_JPanel$vmethods	javax_swing_JPanel;
	_jc_javax_swing_colorchooser_AbstractColorChooserPanel$vmethods	javax_swing_colorchooser_AbstractColorChooserPanel;
	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel$vmethods	javax_swing_colorchooser_DefaultRGBChooserPanel;
};

// Vtype
struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$vtype {
	_jc_type			type;
	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$sub_refs {
	struct _jc_object	*colorChanger;
	struct _jc_object	*spinnerHandler;
	struct _jc_javax_swing_JSlider$object	*R;
	struct _jc_javax_swing_JSlider$object	*G;
	struct _jc_javax_swing_JSlider$object	*B;
	struct _jc_javax_swing_JLabel$object	*RLabel;
	struct _jc_javax_swing_JLabel$object	*GLabel;
	struct _jc_javax_swing_JLabel$object	*BLabel;
	struct _jc_javax_swing_JSpinner$object	*RSpinner;
	struct _jc_javax_swing_JSpinner$object	*GSpinner;
	struct _jc_javax_swing_JSpinner$object	*BSpinner;
};

// Reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$refs {
    _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$sub_refs	javax_swing_colorchooser_DefaultRGBChooserPanel;
    _jc_javax_swing_colorchooser_AbstractColorChooserPanel$sub_refs	javax_swing_colorchooser_AbstractColorChooserPanel;
    _jc_javax_swing_JPanel$sub_refs	javax_swing_JPanel;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$sub_nonrefs {
	jboolean	spinnerChange;
	jboolean	sliderChange;
	jboolean	updateChange;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_JPanel$sub_nonrefs	javax_swing_JPanel;
    _jc_javax_swing_colorchooser_AbstractColorChooserPanel$sub_nonrefs	javax_swing_colorchooser_AbstractColorChooserPanel;
    _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$sub_nonrefs	javax_swing_colorchooser_DefaultRGBChooserPanel;
};

// Object instance structure
struct _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$object {
	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel$vtype	*vtype;
	_jc_javax_swing_colorchooser_DefaultRGBChooserPanel$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$vtype _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_colorchooser_DefaultRGBChooserPanel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_colorchooser_DefaultRGBChooserPanel$class_object;

#endif	/* _JC_javax_swing_colorchooser_DefaultRGBChooserPanel_H_ */
